/****************************************************************************
 * EEPROG Universal programmer 
 * Abstract programmer device manager          
 * 
 * Daniel Quintero <danielqg@infonegocio.com>
 *
 * 04/09/2003 - First version, updated programmers interface
 *              TODO: Create an flexible interface for bit algorithms 
 *
 */

#include "stdhdr.h"
#include "progdev.h"

#define WILLEM
#define EEPROG

#ifdef WILLEM
#include "willem.h"
#endif

#ifdef EEPROG
#include "eeprog.h"
#endif

/* Private data */
struct prog_dev *pd_list = NULL;
struct prog_dev *pd_selected = NULL;


/* Public interface */
int prgdev_init( void ) {

  /* register programmers */
#ifdef WILLEM
  wilInit();
#endif

#ifdef EEPROG
  eepInit();
#endif
  
  /*prgdev_list_devices();*/
  return 1;
}

/* List registered devices to screen */ 
void prgdev_list_devices( void ) {
  struct prog_dev *pd;

  printf("Supported programmers : \n");
  for (pd = pd_list; pd != NULL; pd = pd->next) {
    printf("  \"%s\" - %s\n", pd->name, pd->description);
  }
}

/* Get device by index */
struct prog_dev *prgdev_get_device( int idx ) {
  struct prog_dev *pd;

  pd = pd_list;
  while (pd && idx) {
    pd = pd->next;
    idx--;
  }
  return pd;
}


/* Get device by name */
struct prog_dev *prgdev_get_device_byname( const char *name ) {
  struct prog_dev *pd;

  pd = pd_list;
  while (pd) {
    if (!strcmp(pd->name, name))
      return pd;
    pd = pd->next;
  }
  return NULL;
}


/* Select device */
int prgdev_select_device( const char *name ) {
  struct prog_dev *pd;

  pd = prgdev_get_device_byname(name);
  
  if (!pd)
    return -1;

  pd_selected = pd;
  return 1;
}


/* Get selected device */
struct prog_dev *prgdev_get_selected( void ) {
  return pd_selected;
}


/* register programmer */
int prgdev_register( struct prog_dev *pd ) {
  
  assert(pd);
  pd->next = pd_list;
  pd_list = pd;

  return 0;
}


